@@ -32,7 +32,7 @@ impl Pt {
 }
 
 #[inline]
-fn neighbours(pt: &Pt) -> Vec<Pt> {
+fn successors(pt: &Pt) -> Vec<Pt> {
     let mut ret = Vec::with_capacity(4);
     if 0 < pt.x {
         ret.push(Pt::new(pt.x - 1, pt.y))
@@ -55,7 +55,7 @@ fn corner_to_corner_astar(c: &mut Criterion) {
             assert_ne!(
                 astar(
                     &Pt::new(0, 0),
-                    |n| neighbours(n).into_iter().map(|n| (n, 1)),
+                    |n| successors(n).into_iter().map(|n| (n, 1)),
                     Pt::heuristic,
                     |n| n.x == 64 && n.y == 64,
                 ),
@@ -71,7 +71,7 @@ fn corner_to_corner_bfs(c: &mut Criterion) {
             assert_ne!(
                 bfs(
                     &Pt::new(0, 0),
-                    |n| neighbours(n),
+                    |n| successors(n),
                     |n| n.x == 64 && n.y == 64,
                 ),
                 None
@@ -84,7 +84,7 @@ fn corner_to_corner_dfs(c: &mut Criterion) {
     c.bench_function("corner_to_corner_dfs", |b| {
         b.iter(|| {
             assert_ne!(
-                dfs(Pt::new(0, 0), |n| neighbours(n), |n| n.x == 64 && n.y == 64),
+                dfs(Pt::new(0, 0), |n| successors(n), |n| n.x == 64 && n.y == 64),
                 None
             )
         })
@@ -97,7 +97,7 @@ fn corner_to_corner_dijkstra(c: &mut Criterion) {
             assert_ne!(
                 dijkstra(
                     &Pt::new(0, 0),
-                    |n| neighbours(n).into_iter().map(|n| (n, 1)),
+                    |n| successors(n).into_iter().map(|n| (n, 1)),
                     |n| n.x == 64 && n.y == 64,
                 ),
                 None
@@ -112,7 +112,7 @@ fn corner_to_corner_fringe(c: &mut Criterion) {
             assert_ne!(
                 fringe(
                     &Pt::new(0, 0),
-                    |n| neighbours(n).into_iter().map(|n| (n, 1)),
+                    |n| successors(n).into_iter().map(|n| (n, 1)),
                     Pt::heuristic,
                     |n| n.x == 64 && n.y == 64,
                 ),
@@ -128,7 +128,7 @@ fn corner_to_corner_idastar(c: &mut Criterion) {
             assert_ne!(
                 idastar(
                     &Pt::new(0, 0),
-                    |n| neighbours(n).into_iter().map(|n| (n, 1)),
+                    |n| successors(n).into_iter().map(|n| (n, 1)),
                     Pt::heuristic,
                     |n| n.x == 64 && n.y == 64,
                 ),
@@ -142,7 +142,7 @@ fn corner_to_corner_iddfs(c: &mut Criterion) {
     c.bench_function("corner_to_corner_iddfs", |b| {
         b.iter(|| {
             assert_ne!(
-                iddfs(Pt::new(0, 0), |n| neighbours(n), |n| n.x == 5 && n.y == 5,),
+                iddfs(Pt::new(0, 0), |n| successors(n), |n| n.x == 5 && n.y == 5,),
                 None
             )
         })
@@ -155,7 +155,7 @@ fn no_path_astar(c: &mut Criterion) {
             assert_eq!(
                 astar(
                     &Pt::new(2, 3),
-                    |n| neighbours(n).into_iter().map(|n| (n, 1)),
+                    |n| successors(n).into_iter().map(|n| (n, 1)),
                     |_| 1,
                     |_| false,
                 ),
@@ -167,7 +167,7 @@ fn no_path_astar(c: &mut Criterion) {
 
 fn no_path_bfs(c: &mut Criterion) {
     c.bench_function("no_path_bfs", |b| {
-        b.iter(|| assert_eq!(bfs(&Pt::new(2, 3), |n| neighbours(n), |_| false), None))
+        b.iter(|| assert_eq!(bfs(&Pt::new(2, 3), |n| successors(n), |_| false), None))
     });
 }
 
@@ -177,7 +177,7 @@ fn no_path_dijkstra(c: &mut Criterion) {
             assert_eq!(
                 dijkstra(
                     &Pt::new(2, 3),
-                    |n| neighbours(n).into_iter().map(|n| (n, 1)),
+                    |n| successors(n).into_iter().map(|n| (n, 1)),
                     |_| false,
                 ),
                 None
@@ -192,7 +192,7 @@ fn no_path_fringe(c: &mut Criterion) {
             assert_eq!(
                 fringe(
                     &Pt::new(2, 3),
-                    |n| neighbours(n).into_iter().map(|n| (n, 1)),
+                    |n| successors(n).into_iter().map(|n| (n, 1)),
                     |_| 1,
                     |_| false,
                 ),
