@@ -12,7 +12,7 @@ use std::collections::{BTreeMap, HashMap, VecDeque};
 use std::hash::Hash;
 
 use super::bfs::bfs;
-use matrix::Matrix;
+use crate::matrix::Matrix;
 
 /// Type alias for Edmonds-Karp result.
 pub type EKFlows<N, C> = (Vec<((N, N), C)>, C);
@@ -284,7 +284,7 @@ pub trait EdmondsKarp<C: Copy + Zero + Signed + Ord + Bounded> {
                 }
                 capacity = capacity - max_cancelable;
             } else {
-                panic!("no flow to cancel");
+                unreachable!("no flow to cancel");
             }
         }
     }
